@@ -23,7 +23,6 @@ from osc_lib.command import command
 from osc_lib import exceptions as exc
 from osc_lib import utils
 from oslo_utils import strutils
-import six
 
 from senlinclient.common.i18n import _
 from senlinclient.common import utils as senlin_utils
@@ -345,6 +344,7 @@ class DeleteCluster(command.Command):
                 sys.stdout.write(
                     _("Are you sure you want to delete this cluster(s)"
                       " [y/N]?"))
+                sys.stdout.flush()
                 prompt_response = sys.stdin.readline().lower()
                 if not prompt_response.startswith('y'):
                     return
@@ -358,11 +358,11 @@ class DeleteCluster(command.Command):
         result = {}
         for cid in parsed_args.cluster:
             try:
-                cluster = senlin_client.delete_cluster(
+                cluster_delete_action = senlin_client.delete_cluster(
                     cid, False, parsed_args.force_delete)
-                result[cid] = ('OK', cluster.location.split('/')[-1])
+                result[cid] = ('OK', cluster_delete_action['id'])
             except Exception as ex:
-                result[cid] = ('ERROR', six.text_type(ex))
+                result[cid] = ('ERROR', str(ex))
 
         for rid, res in result.items():
             senlin_utils.print_action_result(rid, res)
@@ -503,7 +503,7 @@ class ResizeCluster(command.Command):
         action_args['min_step'] = min_step
         action_args['strict'] = parsed_args.strict
 
-        resp = senlin_client.cluster_resize(parsed_args.cluster, **action_args)
+        resp = senlin_client.resize_cluster(parsed_args.cluster, **action_args)
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -533,8 +533,12 @@ class ScaleInCluster(command.Command):
         self.log.debug("take_action(%s)", parsed_args)
         senlin_client = self.app.client_manager.clustering
 
-        resp = senlin_client.cluster_scale_in(parsed_args.cluster,
+        resp = senlin_client.scale_in_cluster(parsed_args.cluster,
                                               parsed_args.count)
+        status_code = resp.get('code', None)
+        if status_code in [409]:
+            raise exc.CommandError(_(
+                'Unable to scale in cluster: %s') % resp['error']['message'])
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -564,8 +568,12 @@ class ScaleOutCluster(command.Command):
         self.log.debug("take_action(%s)", parsed_args)
         senlin_client = self.app.client_manager.clustering
 
-        resp = senlin_client.cluster_scale_out(parsed_args.cluster,
+        resp = senlin_client.scale_out_cluster(parsed_args.cluster,
                                                parsed_args.count)
+        status_code = resp.get('code', None)
+        if status_code in [409]:
+            raise exc.CommandError(_(
+                'Unable to scale out cluster: %s') % resp['error']['message'])
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -608,9 +616,9 @@ class ClusterPolicyAttach(command.Command):
                                                  strict=True),
         }
 
-        resp = senlin_client.cluster_attach_policy(parsed_args.cluster,
-                                                   parsed_args.policy,
-                                                   **kwargs)
+        resp = senlin_client.attach_policy_to_cluster(parsed_args.cluster,
+                                                      parsed_args.policy,
+                                                      **kwargs)
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -640,8 +648,8 @@ class ClusterPolicyDetach(command.Command):
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)", parsed_args)
         senlin_client = self.app.client_manager.clustering
-        resp = senlin_client.cluster_detach_policy(parsed_args.cluster,
-                                                   parsed_args.policy)
+        resp = senlin_client.detach_policy_from_cluster(parsed_args.cluster,
+                                                        parsed_args.policy)
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -750,7 +758,8 @@ class ClusterNodeAdd(command.Command):
         self.log.debug("take_action(%s)", parsed_args)
         senlin_client = self.app.client_manager.clustering
         node_ids = parsed_args.nodes.split(',')
-        resp = senlin_client.cluster_add_nodes(parsed_args.cluster, node_ids)
+        resp = senlin_client.add_nodes_to_cluster(parsed_args.cluster,
+                                                  node_ids)
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -792,8 +801,8 @@ class ClusterNodeDel(command.Command):
         destroy = parsed_args.destroy_after_deletion
         destroy = strutils.bool_from_string(destroy, strict=True)
         kwargs = {"destroy_after_deletion": destroy}
-        resp = senlin_client.cluster_del_nodes(parsed_args.cluster, node_ids,
-                                               **kwargs)
+        resp = senlin_client.remove_nodes_from_cluster(
+            parsed_args.cluster, node_ids, **kwargs)
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
@@ -831,8 +840,8 @@ class ClusterNodeReplace(command.Command):
             key = nodepair.split('=')[0]
             value = nodepair.split('=')[1]
             nodepairs[key] = value
-        resp = senlin_client.cluster_replace_nodes(parsed_args.cluster,
-                                                   nodepairs)
+        resp = senlin_client.replace_nodes_in_cluster(parsed_args.cluster,
+                                                      nodepairs)
         if 'action' in resp:
             print('Request accepted by action: %s' % resp['action'])
         else:
